@@ -405,13 +405,14 @@ static inline int s390_gcm(unsigned int function_code,
 					  tag, tag_length, 1, 1);
 		} else {
 			/* encrypt */
-			memset(tag, 0, AES_BLOCK_SIZE);
+			memset(tmp_tag, 0, AES_BLOCK_SIZE);
 			rc = s390_aes_gcm(function_code,
 					  plaintext, ciphertext, text_length,
 					  key, j0, GCM_CTR_WIDTH,
 					  tmp_ctr, GCM_CTR_WIDTH,
 					  aad, aad_length, subkey_h,
-					  tag, tag_length, 1, 1);
+					  tmp_tag, tag_length, 1, 1);
+			memcpy(tag, tmp_tag, tag_length);
 		}
 
 		return rc;
@@ -749,6 +750,10 @@ static inline int s390_aes_gcm_kma(const unsigned char *in_data,
 
 	if (rc >= 0) {
 		ctx->subkey_provided = 1;
+		if (ctx->direction)
+			stats_increment(ICA_STATS_AES_GCM, ALGO_HW, ENCRYPT);
+		else
+			stats_increment(ICA_STATS_AES_GCM, ALGO_HW, DECRYPT);
 		return 0;
 	} else
 		return EIO;
