@@ -232,6 +232,7 @@ int s390_sha1(unsigned char *iv, unsigned char *input_data,
 	int rc = 1;
 	if (sha1_switch)
 		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				sha_constants[SHA_1].hash_length,
 				 message_part, running_length, NULL, SHA_1);
 	if (rc) {
 		rc = s390_sha1_sw(iv, input_data, input_length, output_data,
@@ -250,6 +251,7 @@ int s390_sha224(unsigned char *iv, unsigned char *input_data,
 	int rc = 1;
 	if (sha256_switch)
 		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				sha_constants[SHA_224].hash_length,
 				 message_part, running_length, NULL, SHA_224);
 	if (rc) {
 		rc = s390_sha224_sw(iv, input_data, input_length, output_data,
@@ -268,6 +270,7 @@ int s390_sha256(unsigned char *iv, unsigned char *input_data,
 	int rc = 1;
 	if (sha256_switch)
 		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				sha_constants[SHA_256].hash_length,
 				 message_part, running_length, NULL, SHA_256);
 	if (rc) {
 		rc = s390_sha256_sw(iv, input_data, input_length, output_data,
@@ -286,6 +289,7 @@ int s390_sha384(unsigned char *iv, unsigned char *input_data,
 	int rc = 1;
 	if (sha512_switch)
 		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				 sha_constants[SHA_384].hash_length,
 				 message_part, running_length_lo,
 				 running_length_hi, SHA_384);
 	if (rc) {
@@ -307,6 +311,7 @@ int s390_sha512(unsigned char *iv, unsigned char *input_data,
 	int rc = 1;
 	if (sha512_switch)
 		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				sha_constants[SHA_512].hash_length,
 				 message_part, running_length_lo,
 				 running_length_hi, SHA_512);
 	if (rc) {
@@ -319,3 +324,105 @@ int s390_sha512(unsigned char *iv, unsigned char *input_data,
 
 	return rc;
 }
+
+int s390_sha3_224(unsigned char *iv, unsigned char *input_data,
+		unsigned int input_length, unsigned char *output_data,
+		unsigned int message_part, uint64_t *running_length)
+{
+	int rc = EPERM;
+
+	if (sha3_switch)
+		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				sha_constants[SHA_3_224].hash_length,
+				 message_part, running_length, NULL, SHA_3_224);
+	if (rc == 0)
+		stats_increment(ICA_STATS_SHA3_224, ALGO_HW, ENCRYPT);
+
+	return rc;
+}
+
+int s390_sha3_256(unsigned char *iv, unsigned char *input_data,
+		unsigned int input_length, unsigned char *output_data,
+		unsigned int message_part, uint64_t *running_length)
+{
+	int rc = EPERM;
+
+	if (sha3_switch)
+		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				sha_constants[SHA_3_256].hash_length,
+				 message_part, running_length, NULL, SHA_3_256);
+	if (rc == 0)
+		stats_increment(ICA_STATS_SHA3_256, ALGO_HW, ENCRYPT);
+
+	return rc;
+}
+
+int s390_sha3_384(unsigned char *iv, unsigned char *input_data,
+		uint64_t input_length, unsigned char *output_data,
+		unsigned int message_part, uint64_t *running_length_lo,
+		uint64_t *running_length_hi)
+{
+	int rc = EPERM;
+
+	if (sha3_switch)
+		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				sha_constants[SHA_3_384].hash_length,
+				 message_part, running_length_lo,
+				 running_length_hi, SHA_3_384);
+	if (rc == 0)
+		stats_increment(ICA_STATS_SHA3_384, ALGO_HW, ENCRYPT);
+
+	return rc;
+}
+
+int s390_sha3_512(unsigned char *iv, unsigned char *input_data,
+		uint64_t input_length, unsigned char *output_data,
+		unsigned int message_part, uint64_t *running_length_lo,
+		uint64_t *running_length_hi)
+{
+	int rc = EPERM;
+
+	if (sha3_switch)
+		rc = s390_sha_hw(iv, input_data, input_length, output_data,
+				sha_constants[SHA_3_512].hash_length,
+				 message_part, running_length_lo,
+				 running_length_hi, SHA_3_512);
+	if (rc == 0)
+		stats_increment(ICA_STATS_SHA3_512, ALGO_HW, ENCRYPT);
+
+	return rc;
+}
+
+int s390_shake_128(unsigned char *iv, unsigned char *input_data,
+		uint64_t input_length, unsigned char *output_data, unsigned int output_length,
+		unsigned int message_part, uint64_t *running_length_lo,
+		uint64_t *running_length_hi)
+{
+	int rc = EPERM;
+
+	if (sha3_switch)
+		rc = s390_sha_hw(iv, input_data, input_length, output_data, output_length,
+				 message_part, running_length_lo,
+				 running_length_hi, SHAKE_128);
+	if (rc == 0)
+		stats_increment(ICA_STATS_SHAKE_128, ALGO_HW, ENCRYPT);
+
+	return rc;
+}
+
+int s390_shake_256(unsigned char *iv, unsigned char *input_data,
+		uint64_t input_length, unsigned char *output_data, unsigned int output_length,
+		unsigned int message_part, uint64_t *running_length_lo,
+		uint64_t *running_length_hi)
+{
+	int rc = EPERM;
+
+	if (sha3_switch)
+		rc = s390_sha_hw(iv, input_data, input_length, output_data, output_length,
+				 message_part, running_length_lo,
+				 running_length_hi, SHAKE_256);
+	if (rc == 0)
+		stats_increment(ICA_STATS_SHAKE_256, ALGO_HW, ENCRYPT);
+
+	return rc;
+}
