@@ -12,6 +12,7 @@
 #include <strings.h>
 #include <stdlib.h>
 #include "ica_api.h"
+#include "testcase.h"
 
 #define NR_TESTS 7
 #define NR_RANDOM_TESTS 10000
@@ -241,39 +242,18 @@ unsigned char NIST_TEST_RESULT_CBC_E7[] = {
 	0xda, 0x6c, 0x19, 0x07, 0x8c, 0x6a, 0x9d, 0x1b,
 };
 
-void dump_array(unsigned char *ptr, unsigned int size)
-{
-	unsigned char *ptr_end;
-	unsigned char *h;
-	int i = 1;
-
-	h = ptr;
-	ptr_end = ptr + size;
-	while (h < (unsigned char *)ptr_end) {
-		printf("0x%02x ",(unsigned char ) *h);
-		h++;
-		if (i == 8) {
-			printf("\n");
-			i = 1;
-		} else {
-			++i;
-		}
-	}
-	printf("\n");
-}
-
 void dump_cbc_data(unsigned char *iv, unsigned int iv_length,
 		   unsigned char *key, unsigned int key_length,
 		   unsigned char *input_data, unsigned int data_length,
 		   unsigned char *output_data)
 {
-	printf("IV \n");
+	VV_(printf("IV \n"));
 	dump_array(iv, iv_length);
-	printf("Key \n");
+	VV_(printf("Key \n"));
 	dump_array(key, key_length);
-	printf("Input Data\n");
+	VV_(printf("Input Data\n"));
 	dump_array(input_data, data_length);
-	printf("Output Data\n");
+	VV_(printf("Output Data\n"));
 	dump_array(output_data, data_length);
 }
 
@@ -401,7 +381,7 @@ void load_test_data(unsigned char *data, unsigned int data_length,
 
 }
 
-int kat_aes_cbc(int iteration, int silent)
+int kat_aes_cbc(int iteration)
 {
 	unsigned int data_length;
 	unsigned int iv_length;
@@ -409,12 +389,6 @@ int kat_aes_cbc(int iteration, int silent)
 
 	get_sizes(&data_length, &iv_length, &key_length, iteration);
 
-	if (!silent) {
-		printf("Test Parameters for iteration = %i\n", iteration);
-		printf("key length = %i, data length = %i, iv length = %i\n",
-			key_length, data_length, iv_length);
-	}
-
 	unsigned char iv[iv_length];
 	unsigned char tmp_iv[iv_length];
 	unsigned char expected_iv[iv_length];
@@ -426,6 +400,11 @@ int kat_aes_cbc(int iteration, int silent)
 
 	int rc = 0;
 
+	VV_(printf("Test Parameters for iteration = %i\n", iteration));
+	VV_(printf("key length = %i, data length = %i, iv length = %i\n",
+	    key_length, data_length, iv_length));
+
+
 	load_test_data(input_data, data_length, result, iv, expected_iv,
 		       iv_length, key, key_length, iteration);
 	memcpy(tmp_iv, iv, iv_length);
@@ -433,37 +412,37 @@ int kat_aes_cbc(int iteration, int silent)
 	rc = ica_aes_cbc(input_data, encrypt, data_length, key, key_length,
 			 tmp_iv, 1);
 	if (rc) {
-		printf("ica_aes_cbc encrypt failed with rc = %i\n", rc);
+		VV_(printf("ica_aes_cbc encrypt failed with rc = %i\n", rc));
 		dump_cbc_data(iv, iv_length, key, key_length, input_data,
 			      data_length, encrypt);
 	}
-	if (!silent && !rc) {
-		printf("Encrypt:\n");
+	if (!rc) {
+		VV_(printf("Encrypt:\n"));
 		dump_cbc_data(iv, iv_length, key, key_length, input_data,
 			      data_length, encrypt);
 	}
 
 	if (memcmp(result, encrypt, data_length)) {
-		printf("Encryption Result does not match the known ciphertext!\n");
-		printf("Expected data:\n");
+		VV_(printf("Encryption Result does not match the known ciphertext!\n"));
+		VV_(printf("Expected data:\n"));
 		dump_array(result, data_length);
-		printf("Encryption Result:\n");
+		VV_(printf("Encryption Result:\n"));
 		dump_array(encrypt, data_length);
 		rc++;
 	}
 
 	if (memcmp(expected_iv, tmp_iv, iv_length)) {
-		printf("Update of IV does not match the expected IV!\n");
-		printf("Expected IV:\n");
+		VV_(printf("Update of IV does not match the expected IV!\n"));
+		VV_(printf("Expected IV:\n"));
 		dump_array(expected_iv, iv_length);
-		printf("Updated IV:\n");
+		VV_(printf("Updated IV:\n"));
 		dump_array(tmp_iv, iv_length);
-		printf("Original IV:\n");
+		VV_(printf("Original IV:\n"));
 		dump_array(iv, iv_length);
 		rc++;
 	}
 	if (rc) {
-		printf("AES CBC test exited after encryption\n");
+		VV_(printf("AES CBC test exited after encryption\n"));
 		return rc;
 	}
 
@@ -471,24 +450,24 @@ int kat_aes_cbc(int iteration, int silent)
 	rc = ica_aes_cbc(encrypt, decrypt, data_length, key, key_length,
 			 tmp_iv, 0);
 	if (rc) {
-		printf("ica_aes_cbc decrypt failed with rc = %i\n", rc);
+		VV_(printf("ica_aes_cbc decrypt failed with rc = %i\n", rc));
 		dump_cbc_data(iv, iv_length, key, key_length, encrypt,
 			      data_length, decrypt);
 		return rc;
 	}
 
 
-	if (!silent && !rc) {
-		printf("Decrypt:\n");
+	if (!rc) {
+		VV_(printf("Decrypt:\n"));
 		dump_cbc_data(iv, iv_length, key, key_length, encrypt,
 			      data_length, decrypt);
 	}
 
 	if (memcmp(decrypt, input_data, data_length)) {
-		printf("Decryption Result does not match the original data!\n");
-		printf("Original data:\n");
+		VV_(printf("Decryption Result does not match the original data!\n"));
+		VV_(printf("Original data:\n"));
 		dump_array(input_data, data_length);
-		printf("Decryption Result:\n");
+		VV_(printf("Decryption Result:\n"));
 		dump_array(decrypt, data_length);
 		rc++;
 	}
@@ -500,28 +479,29 @@ int load_random_test_data(unsigned char *data, unsigned int data_length,
 			   unsigned char *key, unsigned int key_length)
 {
 	int rc;
+
 	rc = ica_random_number_generate(data_length, data);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		    rc, errno));
 		return rc;
 	}
 	rc = ica_random_number_generate(iv_length, iv);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		    rc, errno));
 		return rc;
 	}
 	rc = ica_random_number_generate(key_length, key);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		    rc, errno));
 		return rc;
 	}
 	return rc;
 }
 
-int random_aes_cbc(int iteration, int silent, unsigned int data_length)
+int random_aes_cbc(int iteration, unsigned int data_length)
 {
 	int i;
 	int rc = 0;
@@ -532,116 +512,101 @@ int random_aes_cbc(int iteration, int silent, unsigned int data_length)
 	unsigned char input_data[data_length];
 	unsigned char encrypt[data_length];
 	unsigned char decrypt[data_length];
-for (i = 1; i <= 2; i++) {
 
-	unsigned char key[key_length];
+	for (i = 1; i <= 2; i++) {
+		unsigned char key[key_length];
 
-	memset(encrypt, 0x00, data_length);
-	memset(decrypt, 0x00, data_length);
+		memset(encrypt, 0x00, data_length);
+		memset(decrypt, 0x00, data_length);
 
-	load_random_test_data(input_data, data_length, iv, iv_length, key,
-			      key_length);
-	memcpy(tmp_iv, iv, iv_length);
+		load_random_test_data(input_data, data_length, iv, iv_length, key,
+				      key_length);
+		memcpy(tmp_iv, iv, iv_length);
 
-	if (!silent) {
-		printf("Test Parameters for iteration = %i\n", iteration);
-		printf("key length = %i, data length = %i, iv length = %i\n",
-			key_length, data_length, iv_length);
+		VV_(printf("Test Parameters for iteration = %i\n", iteration));
+		VV_(printf("key length = %i, data length = %i, iv length = %i\n",
+		    key_length, data_length, iv_length));
+
+		rc = ica_aes_cbc(input_data, encrypt, data_length, key, key_length,
+				 tmp_iv, 1);
+		if (rc) {
+			VV_(printf("ica_aes_cbc encrypt failed with rc = %i\n", rc));
+			dump_cbc_data(iv, iv_length, key, key_length, input_data,
+				      data_length, encrypt);
+			VV_(printf("Encrypt:\n"));
+			dump_cbc_data(iv, iv_length, key, key_length, input_data,
+				      data_length, encrypt);
+			VV_(printf("AES CBC test exited after encryption\n"));
+			return rc;
+		}
+
+		memcpy(tmp_iv, iv, iv_length);
+
+		rc = ica_aes_cbc(encrypt, decrypt, data_length, key, key_length,
+				 tmp_iv, 0);
+		if (rc) {
+			VV_(printf("ica_aes_cbc decrypt failed with rc = %i\n", rc));
+			dump_cbc_data(iv, iv_length, key, key_length, encrypt,
+				      data_length, decrypt);
+			return rc;
+		}
+
+		if (!rc) {
+			VV_(printf("Decrypt:\n"));
+			dump_cbc_data(iv, iv_length, key, key_length, encrypt,
+				      data_length, decrypt);
+		}
+
+		if (memcmp(decrypt, input_data, data_length)) {
+			VV_(printf("Decryption Result does not match the original data!\n"));
+			VV_(printf("Original data:\n"));
+			dump_array(input_data, data_length);
+			VV_(printf("Decryption Result:\n"));
+			dump_array(decrypt, data_length);
+			rc++;
+			return rc;
+		}
+		key_length += 8;
 	}
 
-	rc = ica_aes_cbc(input_data, encrypt, data_length, key, key_length,
-			 tmp_iv, 1);
-	if (rc) {
-		printf("ica_aes_cbc encrypt failed with rc = %i\n", rc);
-		dump_cbc_data(iv, iv_length, key, key_length, input_data,
-			      data_length, encrypt);
-	}
-	if (!silent && !rc) {
-		printf("Encrypt:\n");
-		dump_cbc_data(iv, iv_length, key, key_length, input_data,
-			      data_length, encrypt);
-	}
-
-	if (rc) {
-		printf("AES CBC test exited after encryption\n");
-		return rc;
-	}
-
-	memcpy(tmp_iv, iv, iv_length);
-
-	rc = ica_aes_cbc(encrypt, decrypt, data_length, key, key_length,
-			 tmp_iv, 0);
-	if (rc) {
-		printf("ica_aes_cbc decrypt failed with rc = %i\n", rc);
-		dump_cbc_data(iv, iv_length, key, key_length, encrypt,
-			      data_length, decrypt);
-		return rc;
-	}
-
-
-	if (!silent && !rc) {
-		printf("Decrypt:\n");
-		dump_cbc_data(iv, iv_length, key, key_length, encrypt,
-			      data_length, decrypt);
-	}
-
-	if (memcmp(decrypt, input_data, data_length)) {
-		printf("Decryption Result does not match the original data!\n");
-		printf("Original data:\n");
-		dump_array(input_data, data_length);
-		printf("Decryption Result:\n");
-		dump_array(decrypt, data_length);
-		rc++;
-		return rc;
-	}
-	key_length += 8;
-}
-
 	return rc;
 }
 
 int main(int argc, char **argv)
 {
-	unsigned int silent = 0;
-	if (argc > 1) {
-		if (strstr(argv[1], "silent"))
-			silent = 1;
-	}
 	int rc = 0;
 	int error_count = 0;
 	int iteration;
 	unsigned int data_length = sizeof(ica_aes_vector_t);
-	for(iteration = 1; iteration <= NR_TESTS; iteration++)	{
-		rc = kat_aes_cbc(iteration, silent);
+
+	set_verbosity(argc, argv);
+
+	for(iteration = 1; iteration <= NR_TESTS; iteration++) {
+		rc = kat_aes_cbc(iteration);
 		if (rc) {
-			printf("kat_aes_cbc failed with rc = %i\n", rc);
+			V_(printf("kat_aes_cbc failed with rc = %i\n", rc));
 			error_count++;
 		} else {
-			if (!silent) {
-				printf("kat_aes_cbc finished successfully\n");
-			}
+			V_(printf("kat_aes_cbc finished.n"));
 		  }
 	}
-	for(iteration = 1; iteration <= NR_RANDOM_TESTS; iteration++)	{
-		//int silent = 1;
-		rc = random_aes_cbc(iteration, silent, data_length);
+	for(iteration = 1; iteration <= NR_RANDOM_TESTS; iteration++) {
+		rc = random_aes_cbc(iteration, data_length);
 		if (rc) {
-			printf("random_aes_cbc failed with rc = %i\n", rc);
+			V_(printf("random_aes_cbc failed with rc = %i\n", rc));
 			error_count++;
 			goto out;
 		} else {
-			if (!silent) {
-				printf("random_aes_cbc finished successfully\n");
-			}
-		  }
+			V_(printf("random_aes_cbc finished.n"));
+		}
 		data_length += sizeof(ica_aes_vector_t);
 	}
 
 out:
 	if (error_count)
-		printf("%i testcases failed\n", error_count);
+		printf("%i AES-CBC tests failed.\n", error_count);
 	else {
-		printf("All AES-CBC testcases finished successfully\n");
+		printf("All AES-CBC tests passed.\n");
 	}
 
 	return rc;
