@@ -12,6 +12,7 @@
 #include <strings.h>
 #include <stdlib.h>
 #include "ica_api.h"
+#include "testcase.h"
 
 #define NR_TESTS 12
 #define NR_RANDOM_TESTS 1000
@@ -352,40 +353,18 @@ unsigned char NIST_TEST_RESULT_CFB_E12[] = {
 
 unsigned int NIST_LCFB_E12 = 8 / 8;
 
-
-void dump_array(unsigned char *ptr, unsigned int size)
-{
-	unsigned char *ptr_end;
-	unsigned char *h;
-	int i = 1;
-
-	h = ptr;
-	ptr_end = ptr + size;
-	while (h < (unsigned char *)ptr_end) {
-		printf("0x%02x ",(unsigned char ) *h);
-		h++;
-		if (i == 8) {
-			printf("\n");
-			i = 1;
-		} else {
-			++i;
-		}
-	}
-	printf("\n");
-}
-
 void dump_cfb_data(unsigned char *iv, unsigned int iv_length,
 		   unsigned char *key, unsigned int key_length,
 		   unsigned char *input_data, unsigned int data_length,
 		   unsigned char *output_data)
 {
-	printf("IV \n");
+	VV_(printf("IV \n"));
 	dump_array(iv, iv_length);
-	printf("Key \n");
+	VV_(printf("Key \n"));
 	dump_array(key, key_length);
-	printf("Input Data\n");
+	VV_(printf("Input Data\n"));
 	dump_array(input_data, data_length);
-	printf("Output Data\n");
+	VV_(printf("Output Data\n"));
 	dump_array(output_data, data_length);
 }
 
@@ -565,7 +544,7 @@ void load_test_data(unsigned char *data, unsigned int data_length,
 
 }
 
-int kat_aes_cfb(int iteration, int silent)
+int kat_aes_cfb(int iteration)
 {
 	unsigned int data_length;
 	unsigned int iv_length;
@@ -573,7 +552,6 @@ int kat_aes_cfb(int iteration, int silent)
 
 	get_sizes(&data_length, &iv_length, &key_length, iteration);
 
-
 	unsigned char iv[iv_length];
 	unsigned char tmp_iv[iv_length];
 	unsigned char expected_iv[iv_length];
@@ -585,6 +563,7 @@ int kat_aes_cfb(int iteration, int silent)
 
 	int rc = 0;
 	unsigned int lcfb;
+
 	memset(encrypt, 0x00, data_length);
 	memset(decrypt, 0x00, data_length);
 
@@ -592,78 +571,75 @@ int kat_aes_cfb(int iteration, int silent)
 		       iv_length, key, key_length, &lcfb, iteration);
 	memcpy(tmp_iv, iv, iv_length);
 
-	if (!silent) {
-		printf("Test Parameters for iteration = %i\n", iteration);
-		printf("key length = %i, data length = %i, iv length = %i,"
-			" lcfb = %i\n", key_length, data_length, iv_length, lcfb);
-	}
+	VV_(printf("Test Parameters for iteration = %i\n", iteration));
+	VV_(printf("key length = %i, data length = %i, iv length = %i,"
+	    " lcfb = %i\n", key_length, data_length, iv_length, lcfb));
 	if (iteration == 3)
-	rc = ica_aes_cfb(input_data, encrypt, lcfb, key, key_length, tmp_iv,
+		rc = ica_aes_cfb(input_data, encrypt, lcfb, key, key_length, tmp_iv,
 			 lcfb, 1);
 	else
-	rc = ica_aes_cfb(input_data, encrypt, data_length, key, key_length,
+		rc = ica_aes_cfb(input_data, encrypt, data_length, key, key_length,
 			 tmp_iv, lcfb, 1);
 	if (rc) {
-		printf("ica_aes_cfb encrypt failed with rc = %i\n", rc);
+		VV_(printf("ica_aes_cfb encrypt failed with rc = %i\n", rc));
 		dump_cfb_data(iv, iv_length, key, key_length, input_data,
 			      data_length, encrypt);
 	}
-	if (!silent && !rc) {
-		printf("Encrypt:\n");
+	if (!rc) {
+		VV_(printf("Encrypt:\n"));
 		dump_cfb_data(iv, iv_length, key, key_length, input_data,
 			      data_length, encrypt);
 	}
 
 	if (memcmp(result, encrypt, data_length)) {
-		printf("Encryption Result does not match the known ciphertext!\n");
-		printf("Expected data:\n");
+		VV_(printf("Encryption Result does not match the known ciphertext!\n"));
+		VV_(printf("Expected data:\n"));
 		dump_array(result, data_length);
-		printf("Encryption Result:\n");
+		VV_(printf("Encryption Result:\n"));
 		dump_array(encrypt, data_length);
 		rc++;
 	}
 
 	if (memcmp(expected_iv, tmp_iv, iv_length)) {
-		printf("Update of IV does not match the expected IV!\n");
-		printf("Expected IV:\n");
+		VV_(printf("Update of IV does not match the expected IV!\n"));
+		VV_(printf("Expected IV:\n"));
 		dump_array(expected_iv, iv_length);
-		printf("Updated IV:\n");
+		VV_(printf("Updated IV:\n"));
 		dump_array(tmp_iv, iv_length);
-		printf("Original IV:\n");
+		VV_(printf("Original IV:\n"));
 		dump_array(iv, iv_length);
 		rc++;
 	}
 	if (rc) {
-		printf("AES OFB test exited after encryption\n");
+		VV_(printf("AES OFB test exited after encryption\n"));
 		return rc;
 	}
 
 	memcpy(tmp_iv, iv, iv_length);
 	if (iteration == 3)
-	rc = ica_aes_cfb(encrypt, decrypt, lcfb, key, key_length, tmp_iv,
-			 lcfb, 0);
+		rc = ica_aes_cfb(encrypt, decrypt, lcfb, key, key_length, tmp_iv,
+		    lcfb, 0);
 	else
-	rc = ica_aes_cfb(encrypt, decrypt, data_length, key, key_length,
-			 tmp_iv, lcfb, 0);
+		rc = ica_aes_cfb(encrypt, decrypt, data_length, key, key_length,
+		    tmp_iv, lcfb, 0);
 	if (rc) {
-		printf("ica_aes_cfb decrypt failed with rc = %i\n", rc);
+		VV_(printf("ica_aes_cfb decrypt failed with rc = %i\n", rc));
 		dump_cfb_data(iv, iv_length, key, key_length, encrypt,
 			      data_length, decrypt);
 		return rc;
 	}
 
-
-	if (!silent && !rc) {
-		printf("Decrypt:\n");
+	if (!rc) {
+		VV_(printf("Decrypt:\n"));
 		dump_cfb_data(iv, iv_length, key, key_length, encrypt,
 			      data_length, decrypt);
 	}
 
 	if (memcmp(decrypt, input_data, data_length)) {
-		printf("Decryption Result does not match the original data!\n");
-		printf("Original data:\n");
+		VV_(printf("Decryption Result does not match the original data!\n"));
+		VV_(printf("Original data:\n"));
 		dump_array(input_data, data_length);
-		printf("Decryption Result:\n");
+		VV_(printf("Decryption Result:\n"));
 		dump_array(decrypt, data_length);
 		rc++;
 	}
@@ -675,29 +651,29 @@ int load_random_test_data(unsigned char *data, unsigned int data_length,
 			   unsigned char *key, unsigned int key_length)
 {
 	int rc;
+
 	rc = ica_random_number_generate(data_length, data);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		    rc, errno));
 		return rc;
 	}
 	rc = ica_random_number_generate(iv_length, iv);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		    rc, errno));
 		return rc;
 	}
 	rc = ica_random_number_generate(key_length, key);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		    rc, errno));
 		return rc;
 	}
 	return rc;
 }
 
-int random_aes_cfb(int iteration, int silent, unsigned int data_length,
-		   unsigned int lcfb)
+int random_aes_cfb(int iteration, unsigned int data_length, unsigned int lcfb)
 {
 	unsigned int iv_length = sizeof(ica_aes_vector_t);
 	unsigned int key_length = AES_KEY_LEN128;
@@ -710,95 +686,91 @@ int random_aes_cfb(int iteration, int silent, unsigned int data_length,
 	unsigned char decrypt[data_length];
 
 	int rc = 0;
+
 	for (key_length = AES_KEY_LEN128; key_length <= AES_KEY_LEN256; key_length += 8) {
-	memset(encrypt, 0x00, data_length);
-	memset(decrypt, 0x00, data_length);
+		memset(encrypt, 0x00, data_length);
+		memset(decrypt, 0x00, data_length);
 
-	load_random_test_data(input_data, data_length, iv, iv_length, key,
-			      key_length);
-	memcpy(tmp_iv, iv, iv_length);
+		load_random_test_data(input_data, data_length, iv, iv_length, key,
+				      key_length);
+		memcpy(tmp_iv, iv, iv_length);
 
-	if (!silent) {
-		printf("Test Parameters for iteration = %i\n", iteration);
-		printf("key length = %i, data length = %i, iv length = %i,"
-			" lcfb = %i\n", key_length, data_length, iv_length, lcfb);
-	}
-	rc = ica_aes_cfb(input_data, encrypt, data_length, key, key_length,
-			 tmp_iv, lcfb, 1);
-	if (rc) {
-		printf("ica_aes_cfb encrypt failed with rc = %i\n", rc);
-		dump_cfb_data(iv, iv_length, key, key_length, input_data,
-			      data_length, encrypt);
-	}
-	if (!silent && !rc) {
-		printf("Encrypt:\n");
-		dump_cfb_data(iv, iv_length, key, key_length, input_data,
-			      data_length, encrypt);
-	}
+		VV_(printf("Test Parameters for iteration = %i\n", iteration));
+		VV_(printf("key length = %i, data length = %i, iv length = %i,"
+		    " lcfb = %i\n", key_length, data_length, iv_length, lcfb));
+		rc = ica_aes_cfb(input_data, encrypt, data_length, key, key_length,
+				 tmp_iv, lcfb, 1);
+		if (rc) {
+			VV_(printf("ica_aes_cfb encrypt failed with rc = %i\n", rc));
+			dump_cfb_data(iv, iv_length, key, key_length, input_data,
+				      data_length, encrypt);
+		}
+		if (!rc) {
+			VV_(printf("Encrypt:\n"));
+			dump_cfb_data(iv, iv_length, key, key_length, input_data,
+				      data_length, encrypt);
+		}
 
-	if (rc) {
-		printf("AES OFB test exited after encryption\n");
-		return rc;
-	}
+		if (rc) {
+			VV_(printf("AES OFB test exited after encryption\n"));
+			return rc;
+		}
 
-	memcpy(tmp_iv, iv, iv_length);
+		memcpy(tmp_iv, iv, iv_length);
 
-	rc = ica_aes_cfb(encrypt, decrypt, data_length, key, key_length,
-			 tmp_iv, lcfb, 0);
-	if (rc) {
-		printf("ica_aes_cfb decrypt failed with rc = %i\n", rc);
-		dump_cfb_data(iv, iv_length, key, key_length, encrypt,
-			      data_length, decrypt);
-		return rc;
-	}
+		rc = ica_aes_cfb(encrypt, decrypt, data_length, key, key_length,
+				 tmp_iv, lcfb, 0);
+		if (rc) {
+			VV_(printf("ica_aes_cfb decrypt failed with rc = %i\n", rc));
+			dump_cfb_data(iv, iv_length, key, key_length, encrypt,
+				      data_length, decrypt);
+			return rc;
+		}
 
+		if (!rc) {
+			VV_(printf("Decrypt:\n"));
+			dump_cfb_data(iv, iv_length, key, key_length, encrypt,
+				      data_length, decrypt);
+		}
 
-	if (!silent && !rc) {
-		printf("Decrypt:\n");
-		dump_cfb_data(iv, iv_length, key, key_length, encrypt,
-			      data_length, decrypt);
-	}
-
-	if (memcmp(decrypt, input_data, data_length)) {
-		printf("Decryption Result does not match the original data!\n");
-		printf("Original data:\n");
-		dump_array(input_data, data_length);
-		printf("Decryption Result:\n");
-		dump_array(decrypt, data_length);
-		rc++;
-	}
+		if (memcmp(decrypt, input_data, data_length)) {
+			VV_(printf("Decryption Result does not match the original data!\n"));
+			VV_(printf("Original data:\n"));
+			dump_array(input_data, data_length);
+			VV_(printf("Decryption Result:\n"));
+			dump_array(decrypt, data_length);
+			rc++;
+		}
 	}
 	return rc;
 }
 
 int main(int argc, char **argv)
 {
-	unsigned int silent = 0;
-	if (argc > 1) {
-		if (strstr(argv[1], "silent"))
-			silent = 1;
-	}
-	int rc = 0;
-	int error_count = 0;
-	int iteration;
-	for(iteration = 1; iteration <= NR_TESTS; iteration++)	{
-		rc = kat_aes_cfb(iteration, silent);
-		if (rc) {
-			printf("kat_aes_cfb failed with rc = %i\n", rc);
-			error_count++;
-		}
-	}
-
 	unsigned int data_length = 1;
 	unsigned int lcfb = 1;
 	unsigned int j;
 	unsigned int rdata;
+	int rc = 0;
+	int error_count = 0;
+	int iteration;
+
+	set_verbosity(argc, argv);
+
+	for(iteration = 1; iteration <= NR_TESTS; iteration++)	{
+		rc = kat_aes_cfb(iteration);
+		if (rc) {
+			V_(printf("kat_aes_cfb failed with rc = %i\n", rc));
+			error_count++;
+		}
+	}
+
 	for(iteration = 1; iteration <= NR_RANDOM_TESTS; iteration++)	{
 		for (j = 1; j <= 3; j++) {
 			if (!(data_length % lcfb)) {
-				rc = random_aes_cfb(iteration, silent, data_length, lcfb);
+				rc = random_aes_cfb(iteration, data_length, lcfb);
 				if (rc) {
-					printf("random_aes_cfb failed with rc = %i\n", rc);
+					V_(printf("random_aes_cfb failed with rc = %i\n", rc));
 					error_count++;
 				}
 			}
@@ -823,9 +795,9 @@ int main(int argc, char **argv)
 		data_length += (rdata % 8) + 1;
 	}
 	if (error_count)
-		printf("%i testcases failed\n", error_count);
+		printf("%i AES-CFB tests failed.\n", error_count);
 	else
-		printf("All AES-CFB testcases finished successfully\n");
+		printf("All AES-CFB tests passed.\n");
 
 	return rc;
 }
