@@ -26,8 +26,6 @@ int test_gcm_kat(int iteration)
 
 	unsigned char* iv = (unsigned char*)&(gcm_kats[iteration].iv);
 	unsigned char* input_data = (unsigned char*)&(gcm_kats[iteration].data);
-	unsigned char encrypt[data_length];
-	unsigned char decrypt[data_length];
 	unsigned char* result = (unsigned char*)&(gcm_kats[iteration].result);
 	unsigned char* aad = (unsigned char*)&(gcm_kats[iteration].aad);
 	unsigned char* key = (unsigned char*)&(gcm_kats[iteration].key);
@@ -35,6 +33,10 @@ int test_gcm_kat(int iteration)
 	unsigned char* t_result = (unsigned char*)&(gcm_kats[iteration].tag);
 
 	int rc = 0;
+	unsigned int vla_length = data_length ? data_length : 1;
+
+	unsigned char encrypt[vla_length];
+	unsigned char decrypt[vla_length];
 
 	VV_(printf("Test Parameters for iteration = %i\n", iteration));
 	VV_(printf("key length = %i, data length = %i, tag length = %i,"
@@ -143,8 +145,6 @@ int test_gcm_kat_update(int iteration)
 
 	unsigned char* iv = (unsigned char*)&(gcm_kats[iteration].iv);
 	unsigned char* input_data = (unsigned char*)&(gcm_kats[iteration].data);
-	unsigned char encrypt[data_length];
-	unsigned char decrypt[data_length];
 	unsigned char* result = (unsigned char*)&(gcm_kats[iteration].result);
 	unsigned char* aad = (unsigned char*)&(gcm_kats[iteration].aad);
 	unsigned char* key = (unsigned char*)&(gcm_kats[iteration].key);
@@ -161,6 +161,11 @@ int test_gcm_kat_update(int iteration)
 	unsigned int  sum_C_len;
 	int rc = 0, i;
 
+	unsigned int vla_length = data_length ? data_length : 1;
+
+	unsigned char encrypt[vla_length];
+	unsigned char decrypt[vla_length];
+
 	VV_(printf("Test Parameters for iteration = %i\n", iteration));
 	VV_(printf("key length = %i, data length = %i, tag length = %i,"
 		"iv length = %i aad_length = %i\n", key_length, data_length,
@@ -318,8 +323,6 @@ int test_gcm_kat_update_aad(int iteration)
 
 	unsigned char* iv = (unsigned char*)&(gcm_kats[iteration].iv);
 	unsigned char* input_data = (unsigned char*)&(gcm_kats[iteration].data);
-	unsigned char encrypt[data_length];
-	unsigned char decrypt[data_length];
 	unsigned char* result = (unsigned char*)&(gcm_kats[iteration].result);
 	unsigned char* aad = (unsigned char*)&(gcm_kats[iteration].aad);
 	unsigned char* key = (unsigned char*)&(gcm_kats[iteration].key);
@@ -337,6 +340,11 @@ int test_gcm_kat_update_aad(int iteration)
 	unsigned int aad_offset;
 	int rc = 0, i;
 
+	unsigned int vla_length = data_length ? data_length : 1;
+
+	unsigned char encrypt[vla_length];
+	unsigned char decrypt[vla_length];
+
 	VV_(printf("Test Parameters for iteration = %i\n", iteration));
 	VV_(printf("key length = %i, data length = %i, tag length = %i,"
 		"iv length = %i aad_length = %i\n", key_length, data_length,
