@@ -1,6 +1,6 @@
 /* This program is released under the Common Public License V1.0
  *
- * You should have recetweaked a copy of Common Public License V1.0 along with
+ * You should have received a copy of Common Public License V1.0 along with
  * with this program.
  */
 
@@ -12,6 +12,7 @@
 #include <strings.h>
 #include <stdlib.h>
 #include "ica_api.h"
+#include "testcase.h"
 
 #define NR_TESTS 5
 #define NR_RANDOM_TESTS 20000
@@ -304,39 +305,18 @@ unsigned char NIST_TEST_RESULT_XTS_E5[] = {
 	0x69, 0x87, 0x83, 0xbf, 0xa4, 0x05, 0x46, 0xe3,
 };
 
-void dump_array(unsigned char *ptr, unsigned int size)
-{
-	unsigned char *ptr_end;
-	unsigned char *h;
-	int i = 1;
-
-	h = ptr;
-	ptr_end = ptr + size;
-	while (h < (unsigned char *)ptr_end) {
-		printf("0x%02x ",(unsigned char ) *h);
-		h++;
-		if (i == 8) {
-			printf("\n");
-			i = 1;
-		} else {
-			++i;
-		}
-	}
-	printf("\n");
-}
-
 void dump_xts_data(unsigned char *tweak, unsigned int tweak_length,
 		   unsigned char *key, unsigned int key_length,
 		   unsigned char *input_data, unsigned int data_length,
 		   unsigned char *output_data)
 {
-	printf("TWEAK \n");
+	VV_(printf("TWEAK \n"));
 	dump_array(tweak, tweak_length);
-	printf("Key \n");
+	VV_(printf("Key \n"));
 	dump_array(key, key_length);
-	printf("Input Data\n");
+	VV_(printf("Input Data\n"));
 	dump_array(input_data, data_length);
-	printf("Output Data\n");
+	VV_(printf("Output Data\n"));
 	dump_array(output_data, data_length);
 }
 
@@ -425,7 +405,7 @@ void load_test_data(unsigned char *data, unsigned int data_length,
 
 }
 
-int kat_aes_xts(int iteration, int silent)
+int kat_aes_xts(int iteration)
 {
 	unsigned int data_length;
 	unsigned int tweak_length;
@@ -443,6 +423,7 @@ int kat_aes_xts(int iteration, int silent)
 	unsigned char result[data_length];
 
 	int rc = 0;
+
 	memset(encrypt, 0x00, data_length);
 	memset(decrypt, 0x00, data_length);
 
@@ -450,46 +431,44 @@ int kat_aes_xts(int iteration, int silent)
 		       tweak_length, key, key_length, iteration);
 	memcpy(tmp_tweak, tweak, tweak_length);
 
-	if (!silent) {
-		printf("Test Parameters for iteration = %i\n", iteration);
-		printf("key length = %i, data length = %i, tweak length = %i,",
-			key_length, data_length, tweak_length);
-	}
+	VV_(printf("Test Parameters for iteration = %i\n", iteration));
+	VV_(printf("key length = %i, data length = %i, tweak length = %i,",
+		key_length, data_length, tweak_length));
 	rc = ica_aes_xts(input_data, encrypt, data_length,
 			 key, key+(key_length/2), (key_length/2),
 			 tmp_tweak, 1);
 	if (rc) {
-		printf("ica_aes_xts encrypt failed with rc = %i\n", rc);
+		VV_(printf("ica_aes_xts encrypt failed with rc = %i\n", rc));
 		dump_xts_data(tweak, tweak_length, key, key_length, input_data,
 			      data_length, encrypt);
 	}
-	if (!silent && !rc) {
-		printf("Encrypt:\n");
+	if (!rc) {
+		VV_(printf("Encrypt:\n"));
 		dump_xts_data(tweak, tweak_length, key, key_length, input_data,
 			      data_length, encrypt);
 	}
 
 	if (memcmp(result, encrypt, data_length)) {
-		printf("Encryption Result does not match the known ciphertext!\n");
-		printf("Expected data:\n");
+		VV_(printf("Encryption Result does not match the known ciphertext!\n"));
+		VV_(printf("Expected data:\n"));
 		dump_array(result, data_length);
-		printf("Encryption Result:\n");
+		VV_(printf("Encryption Result:\n"));
 		dump_array(encrypt, data_length);
 		rc++;
 	}
 
 	if (memcmp(expected_tweak, tmp_tweak, tweak_length)) {
-		printf("Update of TWEAK does not match the expected TWEAK!\n");
-		printf("Expected TWEAK:\n");
+		VV_(printf("Update of TWEAK does not match the expected TWEAK!\n"));
+		VV_(printf("Expected TWEAK:\n"));
 		dump_array(expected_tweak, tweak_length);
-		printf("Updated TWEAK:\n");
+		VV_(printf("Updated TWEAK:\n"));
 		dump_array(tmp_tweak, tweak_length);
-		printf("Original TWEAK:\n");
+		VV_(printf("Original TWEAK:\n"));
 		dump_array(tweak, tweak_length);
 		rc++;
 	}
 	if (rc) {
-		printf("AES XTS test exited after encryption\n");
+		VV_(printf("AES XTS test exited after encryption\n"));
 		return rc;
 	}
 
@@ -498,24 +477,24 @@ int kat_aes_xts(int iteration, int silent)
 			 key, key+(key_length/2), (key_length/2),
 			 tmp_tweak, 0);
 	if (rc) {
-		printf("ica_aes_xts decrypt failed with rc = %i\n", rc);
+		VV_(printf("ica_aes_xts decrypt failed with rc = %i\n", rc));
 		dump_xts_data(tweak, tweak_length, key, key_length, encrypt,
 			      data_length, decrypt);
 		return rc;
 	}
 
 
-	if (!silent && !rc) {
-		printf("Decrypt:\n");
+	if (!rc) {
+		VV_(printf("Decrypt:\n"));
 		dump_xts_data(tweak, tweak_length, key, key_length, encrypt,
 			      data_length, decrypt);
 	}
 
 	if (memcmp(decrypt, input_data, data_length)) {
-		printf("Decryption Result does not match the original data!\n");
-		printf("Original data:\n");
+		VV_(printf("Decryption Result does not match the original data!\n"));
+		VV_(printf("Original data:\n"));
 		dump_array(input_data, data_length);
-		printf("Decryption Result:\n");
+		VV_(printf("Decryption Result:\n"));
 		dump_array(decrypt, data_length);
 		rc++;
 	}
@@ -527,28 +506,29 @@ int load_random_test_data(unsigned char *data, unsigned int data_length,
 			   unsigned char *key, unsigned int key_length)
 {
 	int rc;
+
 	rc = ica_random_number_generate(data_length, data);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		       rc, errno));
 		return rc;
 	}
 	rc = ica_random_number_generate(iv_length, iv);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		       rc, errno));
 		return rc;
 	}
 	rc = ica_random_number_generate(key_length, key);
 	if (rc) {
-		printf("ica_random_number_generate with rc = %i errnor = %i\n",
-		       rc, errno);
+		VV_(printf("ica_random_number_generate with rc = %i errnor = %i\n",
+		       rc, errno));
 		return rc;
 	}
 	return rc;
 }
 
-int random_aes_xts(int iteration, int silent, unsigned int data_length)
+int random_aes_xts(int iteration, unsigned int data_length)
 {
 	int i;
 	int rc = 0;
@@ -559,99 +539,94 @@ int random_aes_xts(int iteration, int silent, unsigned int data_length)
 	unsigned char input_data[data_length];
 	unsigned char encrypt[data_length];
 	unsigned char decrypt[data_length];
-for (i = 1; i <= 2; i++) {
 
-	unsigned char key[key_length];
+	for (i = 1; i <= 2; i++) {
+		unsigned char key[key_length];
 
-	memset(encrypt, 0x00, data_length);
-	memset(decrypt, 0x00, data_length);
+		memset(encrypt, 0x00, data_length);
+		memset(decrypt, 0x00, data_length);
 
-	load_random_test_data(input_data, data_length, iv, iv_length, key,
-			      key_length);
-	memcpy(tmp_iv, iv, iv_length);
+		load_random_test_data(input_data, data_length, iv, iv_length, key,
+				      key_length);
+		memcpy(tmp_iv, iv, iv_length);
 
-	if (!silent) {
-		printf("Test Parameters for iteration = %i\n", iteration);
-		printf("key length = %i, data length = %i, iv length = %i\n",
-			key_length, data_length, iv_length);
+		VV_(printf("Test Parameters for iteration = %i\n", iteration));
+		VV_(printf("key length = %i, data length = %i, iv length = %i\n",
+			key_length, data_length, iv_length));
+		rc = ica_aes_xts(input_data, encrypt, data_length,
+				 key, key+(key_length/2), (key_length/2),
+				 tmp_iv, 1);
+		if (rc) {
+			VV_(printf("ica_aes_xts encrypt failed with rc = %i\n", rc));
+			dump_xts_data(iv, iv_length, key, key_length, input_data,
+				      data_length, encrypt);
+		}
+		if (!rc) {
+			VV_(printf("Encrypt:\n"));
+			dump_xts_data(iv, iv_length, key, key_length, input_data,
+				      data_length, encrypt);
+		}
+
+		if (rc) {
+			VV_(printf("AES XTS test exited after encryption\n"));
+			return rc;
+		}
+
+		memcpy(tmp_iv, iv, iv_length);
+
+		rc = ica_aes_xts(encrypt, decrypt, data_length,
+				 key, key+(key_length/2), (key_length/2),
+				 tmp_iv, 0);
+		if (rc) {
+			VV_(printf("ica_aes_xts decrypt failed with rc = %i\n", rc));
+			dump_xts_data(iv, iv_length, key, key_length, encrypt,
+				      data_length, decrypt);
+			return rc;
+		}
+
+
+		if (!rc) {
+			VV_(printf("Decrypt:\n"));
+			dump_xts_data(iv, iv_length, key, key_length, encrypt,
+				      data_length, decrypt);
+		}
+
+		if (memcmp(decrypt, input_data, data_length)) {
+			VV_(printf("Decryption Result does not match the original data!\n"));
+			VV_(printf("Original data:\n"));
+			dump_array(input_data, data_length);
+			VV_(printf("Decryption Result:\n"));
+			dump_array(decrypt, data_length);
+			rc++;
+			return rc;
+		}
+		key_length = AES_KEY_LEN256 * 2;
 	}
-	rc = ica_aes_xts(input_data, encrypt, data_length,
-			 key, key+(key_length/2), (key_length/2),
-			 tmp_iv, 1);
-	if (rc) {
-		printf("ica_aes_xts encrypt failed with rc = %i\n", rc);
-		dump_xts_data(iv, iv_length, key, key_length, input_data,
-			      data_length, encrypt);
-	}
-	if (!silent && !rc) {
-		printf("Encrypt:\n");
-		dump_xts_data(iv, iv_length, key, key_length, input_data,
-			      data_length, encrypt);
-	}
-
-	if (rc) {
-		printf("AES XTS test exited after encryption\n");
-		return rc;
-	}
-
-	memcpy(tmp_iv, iv, iv_length);
-
-	rc = ica_aes_xts(encrypt, decrypt, data_length,
-			 key, key+(key_length/2), (key_length/2),
-			 tmp_iv, 0);
-	if (rc) {
-		printf("ica_aes_xts decrypt failed with rc = %i\n", rc);
-		dump_xts_data(iv, iv_length, key, key_length, encrypt,
-			      data_length, decrypt);
-		return rc;
-	}
-
-
-	if (!silent && !rc) {
-		printf("Decrypt:\n");
-		dump_xts_data(iv, iv_length, key, key_length, encrypt,
-			      data_length, decrypt);
-	}
-
-	if (memcmp(decrypt, input_data, data_length)) {
-		printf("Decryption Result does not match the original data!\n");
-		printf("Original data:\n");
-		dump_array(input_data, data_length);
-		printf("Decryption Result:\n");
-		dump_array(decrypt, data_length);
-		rc++;
-		return rc;
-	}
-	key_length = AES_KEY_LEN256 * 2;
-}
 
 	return rc;
 }
 
 int main(int argc, char **argv)
 {
-	unsigned int silent = 0;
-	if (argc > 1) {
-		if (strstr(argv[1], "silent"))
-			silent = 1;
-	}
 	int rc = 0;
 	int error_count = 0;
 	int iteration;
 	unsigned int data_length = sizeof(ica_aes_vector_t);
+
+	set_verbosity(argc, argv);
+
 	for(iteration = 1; iteration <= NR_TESTS; iteration++)	{
-		rc = kat_aes_xts(iteration, silent);
+		rc = kat_aes_xts(iteration);
 		if (rc) {
-			printf("kat_aes_xts failed with rc = %i\n", rc);
+			V_(printf("kat_aes_xts failed with rc = %i\n", rc));
 			error_count++;
 		}
 
 	}
 	for(iteration = 1; iteration <= NR_RANDOM_TESTS; iteration++)	{
-		int silent = 1;
-		rc = random_aes_xts(iteration, silent, data_length);
+		rc = random_aes_xts(iteration, data_length);
 		if (rc) {
-			printf("random_aes_xts failed with rc = %i\n", rc);
+			V_(printf("random_aes_xts failed with rc = %i\n", rc));
 			error_count++;
 			goto out;
 		}
@@ -660,9 +635,9 @@ int main(int argc, char **argv)
 
 out:
 	if (error_count)
-		printf("%i testcases failed\n", error_count);
+		printf("%i AES-XTS tests failed.\n", error_count);
 	else
-		printf("All AES-XTS testcases finished successfully\n");
+		printf("All AES-XTS tests passed.\n");
 
 	return rc;
 }
